# Mgen

## Description

Your package provides a set of functions for creating PowerBI master data. It is designed to help users boost the process of data pre-processing.

## Features

- **Function 1**: Brief description of what it does.
- **Function 2**: Brief description of what it does.
- **Function 3**: Brief description of what it does.

## Installation

You can install the package using pip:

```bash
pip install mGenS